@@ -4,7 +4,7 @@
 #define SYSDEPS_H
 
 #undef SKALIBS_TARGET
-#define SKALIBS_TARGET "arm64-apple-darwin25.0.0"
+#define SKALIBS_TARGET "arm64-apple-darwin25.2.0"
 
 #undef SKALIBS_HASCLOCKRT
 #define SKALIBS_HASCLOCKRT
@@ -130,6 +130,11 @@
 
 #undef SKALIBS_HASPPOLL
 
+#undef SKALIBS_HASQSORTR_POSIX
+#define SKALIBS_HASQSORTR_POSIX
+
+#undef SKALIBS_HASQSORTR_FREEBSD
+
 #undef SKALIBS_HASREVOKE
 #define SKALIBS_HASREVOKE
 
@@ -215,6 +220,17 @@
 #undef SKALIBS_HASDLADDR
 #define SKALIBS_HASDLADDR
 
+#undef SKALIBS_HASPIDFD_OPEN
+
+#undef SKALIBS_HASPRCTL
+
+#undef SKALIBS_HASPROCCTL
+
+#undef SKALIBS_HASKEVENT
+#define SKALIBS_HASKEVENT
+
+#undef SKALIBS_HASKQUEUE1
+
 #undef SKALIBS_HASDEVURANDOM
 #define SKALIBS_HASDEVURANDOM
 
